<?php


namespace Controller;

use Exception\CustomException;
use Service\Issue as IssueService;
use Traits\TResponse;
use Util\InstanceProvider;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Issue
{
    use TResponse;

    /**
     * @var IssueService
     */
    private $issueService;

    public function __construct(IssueService $issueService) {
        $this->issueService = $issueService;
    }

    public function findActionsOfExits(Request $request, Response $response)
    {
        try {
            $issueId = $request->getParameter('issueId');
            $actions = $this->issueService->getActionsOfExits($issueId);
            $this->sendResponse($actions, 200);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveSendOutComment(Request $request, Response $response){
        $params = $request->getParameters();
        try {
            $description = $params['DESCRIPTION'];
            if(!empty($params['DOCUMENT'])) {
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($params, 'DOCUMENT', 'PmDevOps/Task');
                $document = $params['DOCUMENT'];
            } else {
                $document = array();
            }

            $taskTypeTarget = $params['TASK_TYPE_TARGET'];
            $commentTypeId = $params['COMMENT_TYPE_ID'];
            $issueId = $params['ISSUE_ID'];

            $this->issueService->sendOutComment($issueId, $document, $taskTypeTarget, $commentTypeId, $description);
        }
        catch(\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
