<?php
namespace Zeedhi\DevOps\Model\Projectmanagement\Repositories;


use Zeedhi\DevOps\Util\Utilities;

class Comments extends \Doctrine\ORM\EntityRepository {

    public function getIssueLastCommentByCreator($issueId, $creatorId, $orgId)
    {
        $query = <<<SQL
        SELECT *
          FROM (
            SELECT DESCRIPTION
              FROM COMMENTS 
             WHERE TASK = :TASK_ID 
                   AND ORGANIZATION = :ORG_ID
          ORDER BY ID DESC)
         WHERE rowNum = 1
SQL;

        $params = array(
            'TASK_ID' => $issueId,
            'ORG_ID' => $orgId
        );

        $result = $this->getEntityManager()->getConnection()->fetchAll($query, $params);

        return empty($result) ? null : $result[0]['DESCRIPTION'];
    }

    public function getCommentsOfTaskExceptCommentedBy($issueId) {
        $query = "
            SELECT *
              FROM (SELECT C.ID, C.ORGANIZATION, C.DESCRIPTION, TO_CHAR(C.CREATED_AT, 'DD/MM/YYYY HH24:MI:SS') AS CREATED_AT, C.TASK, C.CREATED_BY, R.NAME AS CREATED_BY_NAME,
                           'Criado dia '||TO_CHAR(C.CREATED_AT, 'DD/MON/YYYY ','NLS_LANGUAGE = BRAZILIAN PORTUGUESE')||' por '||R.NAME AS NAME,
                           TO_CHAR(C.CREATED_AT, 'YYYYMMDDHHMISS') AS ORDERBY
                      FROM COMMENTS C
                 LEFT JOIN RESOURCE_T R ON(R.ID = C.CREATED_BY)
                     WHERE C.TASK = :TASK_ID)
          ORDER BY ORDERBY DESC";

        $params = array(
            'TASK_ID' => $issueId
        );

        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getFistCommentsWithMessageVersion($issueId,$message,$product) {
        $query = <<<SQL
            SELECT '$message' ||
                    DECODE(PRV.ID,null,'','the version '||PRV.VERSION || '.' || PRV.REVISION  || '.' || PRV.BUILD)||' '||
                    DECODE(OPR.ID,null,'', '(access to the menu option "'||OPR.LABEL||'" from the product '||PRO.NAME||')')
                    AS DESCRIPTION
                    ,COM.ID
            FROM TASK TAS
            JOIN COMMENTS COM ON (TAS.ID = COM.TASK)
            JOIN COMMENT_TYPE COT ON (COT.ID = COM.COMMENT_TYPE_ID AND COT.CONTROL = 'O')
            JOIN PROJECT PRO ON (PRO.ID = :PROJECT)
            LEFT JOIN PRODUCT_VERSION PRV ON (TAS.PRODUCT_VERSION_ID = PRV.ID )
            LEFT JOIN OM_PRODUTO_ELEMENTO OPR On (TAS.MENU_ITEM_ID = OPR.ID)
            WHERE TAS.ID = :TASK_ID

            ORDER BY COM.ID DESC
SQL;

        $params = array(
            'TASK_ID' => $issueId,
            'PROJECT' => $product
        );
        $result = $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        return empty($result) ? null : $result[0];
    }

    public function getMessageVersion($issueId,$message,$product) {
        $query = <<<SQL
            SELECT '$message' ||
                    DECODE(PRV.ID,null,'','the version '||PRV.VERSION || '.' || PRV.REVISION  || '.' || PRV.BUILD)||' '||
                    DECODE(OPR.ID,null,'', '(access to the menu option "'||OPR.LABEL||'" from the product '||PRO.NAME||')')
                    AS DESCRIPTION
            FROM TASK TAS
            LEFT JOIN PRODUCT_VERSION PRV ON (TAS.PRODUCT_VERSION_ID = PRV.ID )
            LEFT JOIN OM_PRODUTO_ELEMENTO OPR On (TAS.MENU_ITEM_ID = OPR.ID)
            JOIN PROJECT PRO ON (PRO.ID = :PROJECT)
            WHERE TAS.ID = :TASK_ID
            AND (OPR.ID IS NOT NULL OR PRV.ID IS NOT NULL)
SQL;

        $params = array(
            'TASK_ID' => $issueId,
            'PROJECT' => $product
        );
        $result = $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        return empty($result) ? null : $result[0]['DESCRIPTION'];
    }

    public function findRecordsOfMeeting($taskArrayId = array(0),$projectArrayId = array(0),$filters = array())
    {
        $filtersString = Utilities::createQueryFiltered($filters);
        $taskStringId = Utilities::getStringForArrayWithDefault($taskArrayId,'0');
        $projectStringId = Utilities::getStringForArrayWithDefault($projectArrayId,'0');
        $query = <<<SQL
        SELECT * FROM (
                  SELECT C.ID, C.ORGANIZATION, C.DESCRIPTION, TO_CHAR(C.CREATED_AT, 'DD/MM/YYYY ') AS CREATED_AT, C.TASK ,
                         'Criado dia '||TO_CHAR(C.CREATED_AT, 'DD/MON/YYYY ','NLS_LANGUAGE = BRAZILIAN PORTUGUESE')||
                         ' por '||R.NAME AS NAME,TAS.PROJECT,C.CREATED_AT AS ORDER_BY,
                         (CASE WHEN PRO.PARENT IS NOT NULL THEN 'Ata da pauta '||  TAS.NAME||' na reunião do dia '||
                         TO_CHAR(PRO.BEGIN_DATE,'DD/MON/YYYY ','NLS_LANGUAGE = BRAZILIAN PORTUGUESE')ELSE
                          'Ata da pauta '||  TAS.NAME END ) AS PROJECT_NAME,
                          (CASE WHEN PRO.PARENT IS NOT NULL THEN PRO.BEGIN_DATE ELSE NULL END) AS BEGIN_DATE
                    FROM COMMENTS C
                    JOIN TASK TAS ON(TAS.ID = C.TASK AND TAS.STATUS = 'A')
                    JOIN PROJECT PRO ON(PRO.ID = TAS.PROJECT AND PRO.STATUS = 'A')
               LEFT JOIN RESOURCE_T R ON(R.ID = C.CREATED_BY)
                   WHERE TAS.ID IN ($taskStringId)
                      OR PRO.ID IN ($projectStringId)
                ORDER BY CREATED_AT DESC)
         WHERE 1 = 1
         $filtersString

         ORDER BY ORDER_BY DESC,BEGIN_DATE DESC NULLS FIRST
SQL;

        return $this->getEntityManager()->getConnection()->fetchAll($query);
    }


}
