<?php
namespace Zeedhi\DevOps\Model\Projectmanagement\Repositories;

use Zeedhi\DevOps\Model\Projectmanagement\Entities;
use Zeedhi\DevOps\Util\Utilities;
use Doctrine\DBAL\Connection;

class TaskType extends \Doctrine\ORM\EntityRepository {
    
    public function findIssueOrderToFrame($issueStatusId){
        $query = <<<SQL
        SELECT ID,ORDER_TO_FRAME,ALLOW_PLAY_TASK_IN_FRAME
          FROM TASK_TYPE
         WHERE ID = :issueStatusId
      ORDER BY ID ASC
SQL;
        $params = array(
            'issueStatusId' => $issueStatusId
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        foreach ($return as &$item) {
            $item['ORDER_TO_FRAME'] = (int)$item['ORDER_TO_FRAME'];
        }

        return $return;
    }

    public function findIssueFramingClassification($issueStatusId){
        $query = <<<SQL
         SELECT TAT.ID ,
                TAT.TASK_TYPE_ID ,
                TAT.CLASSIFICATION_ID ,
                TAT.TASK_ISSUE_CLASSIF,
                CLA.LABEL,
                CLA.LABEL AS LABEL_FORM
           FROM TASK_TYPE_CLASSIFICATION TAT
           JOIN CLASSIFICATION CLA ON(CLA.ID = TAT.CLASSIFICATION_ID)
          WHERE TAT.TASK_TYPE_ID = :issueStatusId
            AND TAT.TASK_ISSUE_CLASSIF = :type
       ORDER BY ID ASC
SQL;
        $params = array(
            'issueStatusId' => $issueStatusId,
            'type' => Entities\TaskTypeClassification::TYPE_LOCKED,
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params);


        return $return;
    }

    public function taskClassificationByIssue($issueId){
        $query = <<<SQL
          SELECT CLA.ID, CLA.LABEL
            FROM TASK ISS
            JOIN TASK_STATUS TST ON (TST.ID = ISS.TASK_STATUS)
            JOIN TASK_TYPE_CLASSIFICATION TAT ON (TAT.TASK_TYPE_ID = TST.TASK_TYPE AND TAT.TASK_ISSUE_CLASSIF = :typeTask )
            JOIN CLASSIFICATION CLA ON (CLA.ID = TAT.CLASSIFICATION_ID)
            WHERE ISS.ID = :issueId
              AND EXISTS (SELECT *
                          FROM TASK ISS
                          JOIN TASK_STATUS TST ON (TST.ID = ISS.TASK_STATUS)
                          JOIN TASK_TYPE_CLASSIFICATION TAT ON (TAT.TASK_TYPE_ID = TST.TASK_TYPE
                                                                AND TAT.TASK_ISSUE_CLASSIF = :typeIssue)
                          WHERE ISS.ID = :issueId
                            AND ISS.CLASSIFICATION = TAT.CLASSIFICATION_ID)
SQL;
        $params = array(
            'issueId' => $issueId,
            'typeTask' => Entities\TaskTypeClassification::TYPE_TASK,
            'typeIssue' => Entities\TaskTypeClassification::TYPE_ISSUE,
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params);


        return $return;
    }

    public function taskClassificationByIssues($issueIds){
        $query = <<<SQL
           SELECT CLA.ID, CLA.LABEL
             FROM TASK ISS
             JOIN TASK_STATUS TST ON (TST.ID = ISS.TASK_STATUS)
             JOIN TASK_TYPE_CLASSIFICATION TAT ON (TAT.TASK_TYPE_ID = TST.TASK_TYPE AND TAT.TASK_ISSUE_CLASSIF = :typeTask )
             JOIN CLASSIFICATION CLA ON (CLA.ID = TAT.CLASSIFICATION_ID)
            WHERE ISS.ID IN (:issueIds)
              AND EXISTS (SELECT *
                          FROM TASK ISS
                          JOIN TASK_STATUS TST ON (TST.ID = ISS.TASK_STATUS)
                          JOIN TASK_TYPE_CLASSIFICATION TAT ON (TAT.TASK_TYPE_ID = TST.TASK_TYPE
                                                                AND TAT.TASK_ISSUE_CLASSIF = :typeIssue)
                          WHERE ISS.ID IN (:issueIds)
                            AND ISS.CLASSIFICATION = TAT.CLASSIFICATION_ID)
         GROUP BY CLA.ID, CLA.LABEL
SQL;
        $params = array(
            'issueIds' => $issueIds,
            'typeTask' => Entities\TaskTypeClassification::TYPE_TASK,
            'typeIssue' => Entities\TaskTypeClassification::TYPE_ISSUE,
        );

        $paramTypes = array(
            'issueIds' => Connection::PARAM_STR_ARRAY
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params, $paramTypes);


        return $return;
    }

    public function findEntranceCommentIssueStatus($issueStatusId){
        $query = <<<SQL
    SELECT TTCT.ID ,
           TTCT.TASK_TYPE_ID AS TASK_TYPE,
           TTCT.COMMENT_TYPE_ID AS COMMENT_TYPE,
           TTCT.IN_OUT_COMMENT ,
           TTCT.ACTION_LABEL ,
           TTCT.STATUS ,
           TTCT.COMMENT_DESCRIPTION AS DESCRIPTION ,
           TTCT.TASK_TYPE_TARGET,
           COTY.NAME AS COMMENT_TYPE_NAME,
          ( SELECT
           rtrim(xmlagg(xmlelement(e,TTCC.CLASSIFICATION_ID  ,',').extract('//text()') order by TTCC.CLASSIFICATION_ID ).GetClobVal(),',') AS ISSUE_CLASSIFICATION
           FROM TASK_TYPE_COMMENT_TYPE_CLASSIF TTCC
           WHERE TTCC.TASK_TYPE_COMMENT_TYPE_ID = TTCT.ID ) AS ISSUE_CLASSIFICATION
      FROM TASK_TYPE_COMMENT_TYPE TTCT
 LEFT JOIN COMMENT_TYPE COTY ON (COTY.ID = TTCT.COMMENT_TYPE_ID )
     WHERE TTCT.TASK_TYPE_ID = :taskType
       AND TTCT.IN_OUT_COMMENT = :IN_COMMENT

SQL;
        $params = array(
            'taskType' => $issueStatusId,
            'IN_COMMENT' => Entities\TaskTypeCommentType::IN_COMMENT,
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        foreach ($return as &$item) {
            $item['ISSUE_CLASSIFICATION'] = Utilities::setSelectMultiInQuery($item['ISSUE_CLASSIFICATION']);
        }
        return $return;
    }

    public function findOutputCommentIssueStatus($issueStatusId){
        $query = <<<SQL
    SELECT TTCT.ID ,
           TTCT.TASK_TYPE_ID AS TASK_TYPE,
           TTCT.COMMENT_TYPE_ID AS COMMENT_TYPE,
           TTCT.IN_OUT_COMMENT ,
           TTCT.ACTION_LABEL ,
           TTCT.STATUS ,
           TTCT.COMMENT_DESCRIPTION AS DESCRIPTION ,
           TTCT.TASK_TYPE_TARGET AS TARGET_STATUS,
           TAST.LABEL AS TARGET_STATUS_NAME,
           COTY.NAME AS COMMENT_TYPE_NAME,
          ( SELECT
           rtrim(xmlagg(xmlelement(e,TTCC.CLASSIFICATION_ID  ,',').extract('//text()') order by TTCC.CLASSIFICATION_ID ).GetClobVal(),',') AS ISSUE_CLASSIFICATION
           FROM TASK_TYPE_COMMENT_TYPE_CLASSIF TTCC
           WHERE TTCC.TASK_TYPE_COMMENT_TYPE_ID = TTCT.ID ) AS ISSUE_CLASSIFICATION
      FROM TASK_TYPE_COMMENT_TYPE TTCT
 LEFT JOIN COMMENT_TYPE COTY ON (COTY.ID = TTCT.COMMENT_TYPE_ID )
 LEFT JOIN TASK_TYPE TAST ON (TAST.ID = TTCT.TASK_TYPE_TARGET )
     WHERE TTCT.TASK_TYPE_ID = :taskType
       AND TTCT.IN_OUT_COMMENT = :OUT_COMMENT

SQL;
        $params = array(
            'taskType' => $issueStatusId,
            'OUT_COMMENT' => Entities\TaskTypeCommentType::OUT_COMMENT,
        );
        $return = $this->getEntityManager()->getConnection()->fetchAll($query, $params);
        foreach ($return as &$item) {
            $item['ISSUE_CLASSIFICATION'] = Utilities::setSelectMultiInQuery($item['ISSUE_CLASSIFICATION']);
        }
        return $return;
    }

}