import { DialogService, IComponentRender } from '@zeedhi/common';
import Messages from '@/services/Messages';
import { Utilities } from '@/services/Utilities';

export class DialogServiceCustom extends DialogService {
	public static showSuccess(text: string) {
		this.show({
			name: 'success_dialog',
			type: 'success',
			title: 'Sucesso',
			text,
		});
	}

	public static showError(text: string) {
		this.show({
			name: 'error_dialog',
			type: 'error',
			title: 'Erro',
			text,
		});
	}

	public static showWarning(text: string) {
		this.show({
			name: 'error_dialog',
			type: 'warning',
			title: 'Alerta',
			text,
		});
	}

	public static showErrorBackend(error: any) {
		let msg = '';
		if (error.response && error.response.data && error.response.data.error) {
			msg = `<b>${error.response.data.error}</b>`;
		} else if (error.stack) {
			msg = error.stack;
		} else if (error.message) {
			msg = error.message;
		} else {
			msg = Messages.ERROR_DEAFULT;
		}
		this.show({
			name: 'error_dialog',
			type: 'error',
			title: 'Erro',
			text: msg,
		});
	}

	public static confirmMessage(message: string, buttonYes?: IComponentRender[], buttonNo?: IComponentRender[]) {
		const btnYes = buttonYes || [{
			name: Utilities.getNameDynamic('yes'),
			component: 'ZdButton',
			label: 'Sim',
			outline: false,
			events: {
				click: (() => {
					DialogService.hide();
				}),
			},
		}];

		const btnNo = buttonNo || [{
			name: Utilities.getNameDynamic('no'),
			component: 'ZdButton',
			label: 'Não',
			outline: true,
			events: {
				click: (() => {
					DialogService.hide();
				}),
			},
		}];

		const buttons: IComponentRender[] = [...btnNo, ...btnYes];

		DialogService.show({
			name: Utilities.getNameDynamic('pm-confirm-dialog-'),
			type: 'warning',
			title: 'Atenção',
			text: message,
			buttons,
		});
	}
}
